==> nextcloud-28.0.5.tar.bz2: nextcloud/apps/theming/l10n/ja.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "名前が長すぎます",
    "The given web address is too long" : "Webアドレスが長すぎます",
    "The given web address is not a valid URL" : "指定されたWebアドレスは有効なURLではありません",
    "The given legal notice address is too long" : "指定された法的通知アドレスが長すぎます",
    "The given legal notice address is not a valid URL" : "指定された法的通知アドレスは有効なURLではありません",
    "The given privacy policy address is too long" : "指定された個人情報保護方針のアドレスが長すぎます",
    "The given privacy policy address is not a valid URL" : "指定された個人情報保護方針アドレスは有効なURLではありません",
    "The given slogan is too long" : "スローガンが長すぎます",
    "The given color is invalid" : "無効な色です",
    "Disable-user-theming should be true or false" : "Disable-user-themingは、trueまたはfalseで指定してください",
    "Saved" : "保存済み",
    "Invalid app given" : "無効なアプリが指定されました",
    "Invalid setting key" : "無効な設定キー",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードファイルサイズが、php.ini の upload_max_filesize を超過しています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時領域フォルダーがありません",
    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
    "No file uploaded" : "ファイルがアップロードされていません",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "あなたはすでにカスタムテーマを使用しています。 テーマ設定の設定が上書きされる可能性があります。",
    "Theming" : "テーマ",
    "Appearance and accessibility" : "外観とアクセシビリティ",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "テーマ別アプリは有効ですが、PHPモジュール「imagick」が有効ではありません。ファビコン生成を正しく行うには、このモジュールをインストールし、有効化する必要があります。",
    "Dark theme with high contrast mode" : "ハイコントラストモードのダークテーマ",
    "Enable dark high contrast mode" : "ハイコントラストモードのダークテーマを有効化",
    "Similar to the high contrast mode, but with dark colours." : "暗い色調でのハイコントラストモード",
    "Dark theme" : "ダークテーマ",
    "Enable dark theme" : "ダークテーマを有効にする",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "全体的な明度と明るさを下げることで目を楽にする暗い色調のテーマ",
    "System default theme" : "システムのデフォルトに合わせたテーマ",
    "Enable the system default" : "システムデフォルトを有効化",
    "Using the default system appearance." : "デフォルトの外観を利用",
    "Dyslexia font" : "Dyslexia フォント",
    "Enable dyslexia font" : "Dyslexia フォントを有効にする",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexicは、ディスレクシアによって引き起こされる一般的な読み間違いの一部を軽減するためにデザインされた、無料で利用できる書体/フォントです。",
    "High contrast mode" : "ハイ・コントラストモード",
    "Enable high contrast mode" : "ハイ・コントラストモードを有効にする。",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "操作をわかりやすくするためのハイ・コントラストモード。\n見た目の美しさは低下しますが、明確さが向上します。",
    "Light theme" : "ライトテーマ",
    "Enable the default light theme" : "デフォルトの明るいテーマを有効化",
    "The default light appearance." : "デフォルトの明るい外観",
    "Legal notice" : "法的通知",
    "Privacy policy" : "個人情報保護方針",
    "Adjust the Nextcloud theme" : "Nextcloudテーマを調整する",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "テーマでは、あなたのインスタンスとサポートされたクライアントのルック＆フィールを簡単に変更できます。この変更はすべてのユーザーが対象となります。",
    "Advanced options" : "詳細オプション",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "SVG画像をサポートするPHP拡張機能 ImageMagick をインストールすると、アップロードされたロゴと色に基づいてファビコンを自動生成することができます。",
    "Name" : "名前",
    "Web link" : "Webリンク",
    "a safe home for all your data" : "あなたのすべてのデータを安全に保管する場所",
    "Slogan" : "標語",
    "Color" : "色",
    "Logo" : "ロゴ",
    "Upload new logo" : "新しいロゴをアップロード",
    "Background and login image" : "背景とログイン画像",
    "Upload new background and login image" : "新しい背景とログイン画像",
    "Legal notice link" : "法的通知のリンク",
    "Privacy policy link" : "個人情報保護方針のリンク",
    "Header logo" : "ヘッダーロゴ",
    "Upload new header logo" : "新しいヘッダーロゴをアップロード",
    "Favicon" : "Favicon",
    "Upload new favicon" : "新しいfaviconをアップロード",
    "User settings" : "ユーザー設定",
    "Disable user theming" : "ユーザー毎のテーマを無効",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "このサーバーの外観のカスタマイズと画像を変更を変更できますが、さらにユーザーは背景と色を変更できます。外観のカスタマイズを強制する場合は以下のチェック設定をオンにしてください。",
    "Background" : "背景",
    "Customization has been disabled by your administrator" : "カスタマイズは管理者によって無効にされています",
    "Set a custom background" : "背景を設定",
    "Keyboard shortcuts" : "キーボードショートカット",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "場合によっては、キーボードショートカットがアクセシビリティツールに干渉することがあります。ツールに正しくフォーカスできるようにするために、ここですべてのキーボード ショートカットを無効にできます。この場合、アプリで使用可能なすべてのショートカットも無効になります。",
    "Disable all keyboard shortcuts" : "全てのキーボードショートカットを無効化",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ユニバーサルアクセスは私たちにとって非常に重要なことです。そのためウェブ標準に従い、マウスやスクリーンリーダーなどの支援ソフトウェアが無くても全ての機能をご利用いただけるようにチェックしています。AAAレベルのハイコントラストのテーマを採用することで、{guidelines} Webコンテンツアクセシビリティガイドライン2.1  {linkend} のAAAレベルに準拠することを目指しています。",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "何か問題を見つけた場合は、{issuetracker}私たちの問題トラッカー{linkend}で遠慮なく報告してください。参加したい場合は、{designteam}私たちのデザイン チーム{linkend}に参加してください!",
    "Current selected app: {app}, position {position} of {total}" : "現在の選択済みアプリ: {app}、{total} の {position} 番目",
    "Move up" : "上に移動",
    "Move down" : "下に移動",
    "Custom background" : "カスタム背景",
    "Default background" : "デフォルト背景",
    "Change color" : "色を変える",
    "No background" : "背景なし",
    "Select a background from your files" : "あなたのファイルから背景を選択する",
    "Select background" : "背景を選択する",
    "No background has been selected" : "選択済みの背景はありません",
    "Theme selection is enforced" : "テーマ選択を強制",
    "Navigation bar settings" : "ナビゲーションバーの設定",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "アプリのナビゲーションバーで使用されるアプリの順序を設定できます。最初のエントリは、ログイン後またはロゴをクリックしたときに開かれるデフォルトのアプリになります。",
    "The default app can not be changed because it was configured by the administrator." : "デフォルトのアプリは、管理者によって設定されたため変更できません。",
    "The app order was changed, to see it in action you have to reload the page." : "アプリの順番が変更されました。それを実際に見るには、ページをリロードする必要があります。",
    "Reset default app order" : "デフォルトのアプリの順序をリセットする",
    "Could not set the app order" : "アプリの順番を設定できませんでした",
    "Could not reset the app order" : "アプリの順番をリセットできませんでした",
    "Default app" : "デフォルトアプリ",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "デフォルトのアプリは、ログイン後やメニューのロゴをクリックした後に開かれるアプリです。",
    "Use custom default app" : "カスタムデフォルトアプリを使用する",
    "Global default app" : "Global default app",
    "Global default apps" : "Global default apps",
    "Default app priority" : "デフォルトアプリの優先順位",
    "If an app is not enabled for a user, the next app with lower priority is used." : "あるアプリがユーザーに対して有効になっていない場合、次の優先順位のアプリが使用されます。",
    "Could not set global default apps" : "グローバルなデフォルトアプリを設定できなかった",
    "Reset to default" : "デフォルトに戻す",
    "Upload" : "アップロード",
    "Remove background image" : "背景画像を削除",
    "Select a custom color" : "カスタムカラーを選択"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.13.tar.bz2: nextcloud/apps/theming/l10n/ja.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "名前が長すぎます",
    "The given web address is too long" : "Webアドレスが長すぎます",
    "The given web address is not a valid URL" : "指定されたWebアドレスは有効なURLではありません",
    "The given legal notice address is too long" : "指定された法的通知アドレスが長すぎます",
    "The given legal notice address is not a valid URL" : "指定された法的通知アドレスは有効なURLではありません",
    "The given privacy policy address is too long" : "指定された個人情報保護方針のアドレスが長すぎます",
    "The given privacy policy address is not a valid URL" : "指定された個人情報保護方針アドレスは有効なURLではありません",
    "The given slogan is too long" : "スローガンが長すぎます",
    "The given color is invalid" : "無効な色です",
    "Invalid setting key" : "無効な設定キー",
    "Saved" : "保存済み",
    "Invalid app given" : "無効なアプリが指定されました",
    "Invalid type for setting \"defaultApp\" given" : "\"defaultApp\"の設定に無効なタイプが指定されました",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードファイルサイズが、php.ini の upload_max_filesize を超過しています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時領域フォルダーがありません",
    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
    "No file uploaded" : "ファイルがアップロードされていません",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "あなたはすでにカスタムテーマを使用しています。 テーマ設定の設定が上書きされる可能性があります。",
    "Theming" : "テーマ",
    "Appearance and accessibility" : "外観とアクセシビリティ",
    "PHP Imagick module" : "PHP Imagickモジュール",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "テーマ別アプリは有効ですが、PHPモジュール「imagick」が有効ではありません。ファビコン生成を正しく行うには、このモジュールをインストールし、有効化する必要があります。",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "このインスタンス内のPHPモジュール\"imagick\"はSVGをサポートしていません。互換性を高めるために、インストールすることをおすすめします。",
    "Dark theme with high contrast mode" : "ハイコントラストモードのダークテーマ",
    "Enable dark high contrast mode" : "ハイコントラストモードのダークテーマを有効化",
    "Similar to the high contrast mode, but with dark colours." : "暗い色調でのハイコントラストモード",
    "Dark theme" : "ダークテーマ",
    "Enable dark theme" : "ダークテーマを有効にする",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "全体的な明度と明るさを下げることで目を楽にする暗い色調のテーマ",
    "System default theme" : "システムのデフォルトに合わせたテーマ",
    "Enable the system default" : "システムデフォルトを有効化",
    "Using the default system appearance." : "デフォルトの外観を利用",
    "Dyslexia font" : "Dyslexia フォント",
    "Enable dyslexia font" : "Dyslexia フォントを有効にする",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexicは、ディスレクシアによって引き起こされる一般的な読み間違いの一部を軽減するためにデザインされた、無料で利用できる書体/フォントです。",
    "High contrast mode" : "ハイ・コントラストモード",
    "Enable high contrast mode" : "ハイ・コントラストモードを有効にする。",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "操作をわかりやすくするためのハイ・コントラストモード。\n見た目の美しさは低下しますが、明確さが向上します。",
    "Light theme" : "ライトテーマ",
    "Enable the default light theme" : "デフォルトの明るいテーマを有効化",
    "The default light appearance." : "デフォルトの明るい外観",
    "Legal notice" : "法的通知",
    "Privacy policy" : "個人情報保護方針",
    "Adjust the Nextcloud theme" : "Nextcloudテーマを調整する",
    "Could not set global default apps" : "グローバルなデフォルトアプリを設定できなかった",
    "Navigation bar settings" : "ナビゲーションバーの設定",
    "Default app" : "デフォルトアプリ",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "デフォルトのアプリは、ログイン後やメニューのロゴをクリックした後に開かれるアプリです。",
    "Use custom default app" : "カスタムデフォルトアプリを使用する",
    "Global default app" : "Global default app",
    "Global default apps" : "Global default apps",
    "Default app priority" : "デフォルトアプリの優先順位",
    "If an app is not enabled for a user, the next app with lower priority is used." : "あるアプリがユーザーに対して有効になっていない場合、次の優先順位のアプリが使用されます。",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "テーマでは、あなたのインスタンスとサポートされたクライアントのルック＆フィールを簡単に変更できます。この変更はすべてのユーザーが対象となります。",
    "Name" : "名前",
    "Web link" : "Webリンク",
    "Slogan" : "標語",
    "a safe home for all your data" : "あなたのすべてのデータを安全に保管する場所",
    "Legal notice link" : "法的通知のリンク",
    "Privacy policy link" : "個人情報保護方針のリンク",
    "Background and color" : "背景と色",
    "Primary color" : "プライマリカラー",
    "Background color" : "背景色",
    "Remove background image" : "背景画像を削除",
    "Favicon" : "Favicon",
    "Logo" : "ロゴ",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "このサーバーの外観のカスタマイズと画像を変更を変更できますが、さらにユーザーは背景と色を変更できます。外観のカスタマイズを強制する場合は以下のチェック設定をオンにしてください。",
    "Disable user theming" : "ユーザー毎のテーマを無効",
    "Current selected app: {app}, position {position} of {total}" : "現在の選択済みアプリ: {app}、{total} の {position} 番目",
    "Move up" : "上に移動",
    "Move down" : "下に移動",
    "Theme selection is enforced" : "テーマ選択を強制",
    "Could not set the app order" : "アプリの順番を設定できませんでした",
    "Could not reset the app order" : "アプリの順番をリセットできませんでした",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "アプリのナビゲーションバーで使用されるアプリの順序を設定できます。最初のエントリは、ログイン後またはロゴをクリックしたときに開かれるデフォルトのアプリになります。",
    "The default app can not be changed because it was configured by the administrator." : "デフォルトのアプリは、管理者によって設定されたため変更できません。",
    "The app order was changed, to see it in action you have to reload the page." : "アプリの順番が変更されました。それを実際に見るには、ページをリロードする必要があります。",
    "Reset default app order" : "デフォルトのアプリの順序をリセットする",
    "Select a background from your files" : "あなたのファイルから背景を選択する",
    "Select background" : "背景を選択する",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "背景は、既定のセットのイメージ、カスタムアップロードされたイメージ、または無地に設定できます。",
    "Custom background" : "カスタム背景",
    "Plain background" : "シンプルな背景",
    "Default background" : "デフォルト背景",
    "Keyboard shortcuts" : "キーボードショートカット",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "場合によっては、キーボードショートカットがアクセシビリティツールに干渉することがあります。ツールに正しくフォーカスできるようにするために、ここですべてのキーボード ショートカットを無効にできます。この場合、アプリで使用可能なすべてのショートカットも無効になります。",
    "Disable all keyboard shortcuts" : "全てのキーボードショートカットを無効化",
    "Could not set primary color" : "プライマリカラーを設定できませんでした",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "重要な要素を強調表示するための原色を設定します。主ボタンなどの要素に使用される色は、アクセシビリティ要件を満たすように調整されるため、多少異なる場合があります。",
    "Reset primary color" : "プライマリカラーをリセット",
    "Reset to default" : "デフォルトに戻す",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ユニバーサルアクセスは私たちにとって非常に重要なことです。そのためウェブ標準に従い、マウスやスクリーンリーダーなどの支援ソフトウェアが無くても全ての機能をご利用いただけるようにチェックしています。 {linkstart}Webコンテンツアクセシビリティガイドライン{linkend} 2.1 のAAレベルに準拠することを、また、ハイコントラストのテーマを採用することでAAAレベルにまで準拠することを目指しています。",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "何か問題を見つけた場合は、{issuetracker}私たちの問題トラッカー{linkend}で遠慮なく報告してください。参加したい場合は、{designteam}私たちのデザイン チーム{linkend}に参加してください!",
    "Unable to apply the setting." : "設定を適用できません。",
    "Appearance and accessibility settings" : "外観とアクセシビリティの設定",
    "Misc accessibility options" : "その他のアクセシビリティオプション",
    "Enable blur background filter (may increase GPU load)" : "背景ぼかしフィルターを有効にする (GPU負荷が増加する可能性があります)",
    "Customization has been disabled by your administrator" : "カスタマイズは管理者によって無効にされています",
    "Disable-user-theming should be true or false" : "Disable-user-themingは、trueまたはfalseで指定してください",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "基本色は、重要なボタンなどの要素を強調表示するために使用されます。現在のカラースキーマに応じて若干調整される場合があります。",
    "Header logo" : "ヘッダーロゴ",
    "Upload new header logo" : "新しいヘッダーロゴをアップロード",
    "Upload new favicon" : "新しいfaviconをアップロード",
    "User settings" : "ユーザー設定",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "背景画像の代わりに、無地の背景色を設定することもできます。背景画像を使用する場合、この色を変更すると、アプリメニューアイコンの色に影響します。",
    "Upload new logo" : "新しいロゴをアップロード",
    "Upload new background and login image" : "新しい背景とログイン画像",
    "Background and login image" : "背景とログイン画像",
    "Advanced options" : "詳細オプション",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "SVG画像をサポートするPHP拡張機能 ImageMagick をインストールすると、アップロードされたロゴと色に基づいてファビコンを自動生成することができます。",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ユニバーサルアクセスは私たちにとって非常に重要なことです。そのためウェブ標準に従い、マウスやスクリーンリーダーなどの支援ソフトウェアが無くても全ての機能をご利用いただけるようにチェックしています。AAAレベルのハイコントラストのテーマを採用することで、{guidelines} Webコンテンツアクセシビリティガイドライン2.1  {linkend} のAAAレベルに準拠することを目指しています。",
    ". Unable to apply the setting." : "設定を適用できません。",
    "No background has been selected" : "選択済みの背景はありません",
    "Select a custom color" : "カスタムカラーを選択",
    "Upload" : "アップロード"
},
"nplurals=1; plural=0;");
